# radiozilla
📻 Python Radio Browser API wrapper with fully Type Hinting and Documentation

# Installation
`pip install radiozilla`
# Examples
```py
from radiozilla.radios import Radio


radio = Radio()
radio.search("BBC")
```
![](assets/image.png)